<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Gaming.UI

Windows Runtime (WinRT) APIs for for the `Windows.Gaming.UI` namespace.

This package provides the `winrt.windows.gaming.ui` module.
